@@ -170,6 +170,7 @@ int get_device( int fdp, GEOMETRY *geo)
         int			device;
         int			tmp_flags;
         int			biosdrive_set=0;
+        int			hdadd=0;
         
         if( fstat(fdp,&st)<0 )
         	return 0;
@@ -204,6 +205,18 @@ int get_device( int fdp, GEOMETRY *geo)
 			geo->device=MINOR(device)&3;
 		break;
 
+	case MAJOR_XT:
+		die(-1, "Sorry, xt disk support removed\n");
+		break;
+		
+	case MAJOR_SD:
+		hdadd+=last_dev(DEVPATH, MAJOR_IDE3, 64);
+	case MAJOR_IDE3:
+		hdadd+=last_dev(DEVPATH, MAJOR_IDE2, 64);
+	case MAJOR_IDE2:
+		hdadd+=last_dev(DEVPATH, MAJOR_IDE1, 64);
+	case MAJOR_IDE1:
+		hdadd+=last_dev(DEVPATH, MAJOR_HD, 64);
 	case MAJOR_HD:
 		if(ioctl(fd,HDIO_GETGEO,&hdgeo)<0)
 			die(errno,dev_name(device));
@@ -212,45 +225,20 @@ int get_device( int fdp, GEOMETRY *geo)
 		geo->cylinders=hdgeo.cylinders;
 		geo->sectors=hdgeo.sectors;
 		geo->start=hdgeo.start;
-		if(!biosdrive_set)
-			geo->device=0x80+(MINOR(device)>>6);
-		break;
-	case MAJOR_XT:
-	case MAJOR_IDE2:
-		if(ioctl(fd,HDIO_GETGEO,&hdgeo)<0)
-			die(errno,dev_name(device));
-		
-		geo->heads=hdgeo.heads;
-		geo->cylinders=hdgeo.cylinders;
-		geo->sectors=hdgeo.sectors;
-		geo->start=hdgeo.start;
-		if(!biosdrive_set)
-			geo->device=0x80+(MINOR(device)>>6)+
-				last_dev(DEVPATH,MAJOR_HD,64);
-		break;
-	case MAJOR_SD:
-		if(ioctl(fd,HDIO_GETGEO,&hdgeo)<0)
-			die(errno,dev_name(device));
 			
-		geo->heads=hdgeo.heads;
-		geo->cylinders=hdgeo.cylinders;
-		geo->sectors=hdgeo.sectors;
-		geo->start=hdgeo.start;
-			
-		// LILO does it something like this...
-		// I don't know if this works as I don't have SCSI
-		// disks...
-		if(!hdgeo.sectors){
-			die(-1,"Invalid harddisk geometry gotten\n"
-			       " (some1 should add the option to manually tell geometry!)\n");
+		if(!hdgeo.sectors)
+			die(-1,"Invalid harddisk geometry gotten\n");
+
+		if(!biosdrive_set){
+			if(MAJOR(device)==MAJOR_SD)
+				geo->device=0x80+(MINOR(device)>>4)+hdadd;
+			else
+				geo->device=0x80+(MINOR(device)>>6)+hdadd;
 		}
-		if(!biosdrive_set)
-			geo->device=0x80+(MINOR(device)>>4)+
-				last_dev(DEVPATH,MAJOR_HD,64);
 		break;
 		
 	default:
-		die(-1,"Dunno how to handle device %s.",dev_name(device));
+		die(-1,"Don't know how to handle device %s.",dev_name(device));
 	}
 
 	return 1;					
