@@ -107,7 +107,7 @@ int install_it( void )
 	// Get the bootsector into memory
 	fd=get_binary("bsect",CHOS_BSECT,"bootsector",&a);
 	
-	if(a!=444)
+	if(a!=PARTTABLE_OFF-2)
 		die(-1,"%s is of invalid size\n",tmpstr);
 	
 	if(!(bs=(ChosBsect*)malloc(a)))
